@@ -12,6 +12,8 @@ from selenium.webdriver.remote.script_key import ScriptKey
 from selenium.webdriver.common.proxy import Proxy, ProxyType
 from selenium import webdriver
 from selenium.webdriver.firefox.service import Service as FireFoxService
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
+
 
 #Main Simple Selenium class
 #@for_all_methods(stop_driver_on_error)
@@ -28,6 +30,7 @@ class WebDriver (ElementLocation):
         save_profile=False,
         profile_directory=None,
         profile_name=None,
+        desired_capabilities=None,
         show_selenium_cmd=False,
         use_proxy=False,
         proxy_host=None,
@@ -95,6 +98,7 @@ class WebDriver (ElementLocation):
         self.startupOptions['save_profile']=save_profile
         self.startupOptions['profile_directory']=profile_directory
         self.startupOptions['profile_name']=profile_name
+        self.startupOptions['desired_capabilities']=desired_capabilities
         self.startupOptions['show_selenium_cmd']=show_selenium_cmd
         self.startupOptions['use_proxy']=use_proxy
         self.startupOptions['proxy_host']=proxy_host
@@ -201,7 +205,7 @@ class WebDriver (ElementLocation):
             service=Service(self.webdriverExecutablePath)
             if startupOptions['show_selenium_cmd']==False:
                 service.creationflags = CREATE_NO_WINDOW #Hides cmd prompt that pops up
-            driver=webdriver.Chrome(service=service,options=chrome_options)
+            driver=webdriver.Chrome(service=service,options=chrome_options,desired_capabilities=startupOptions['desired_capabilities'])
 
             #Anti-bot detection evasion part 2
             driver.execute_script("""
@@ -318,9 +322,13 @@ class WebDriver (ElementLocation):
             
 
     def close(self):
-        #Close webdriver
-        self.driver.close()
-        self.driver.quit()
+        try:
+            #Close webdriver
+            self.driver.close()
+            self.driver.quit()
+        except:
+            #Quit webdriver if close fails
+            self.driver.quit()
 
     def close_active_tab(self):
         self.driver.close()
